@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $superduper: input.c,v 1.8 2003/09/24 18:01:50 sam Exp $
+ * $superduper: input.c,v 1.9 2004/04/24 12:19:00 sam Exp $
  */
 #include "config.h"
 
@@ -24,6 +24,10 @@
 #include <assert.h>
 #endif /* HAVE_ASSERT_H */
 
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif /* HAVE_SYS_TYPES_H */
+
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif /* HAVE_SYS_SOCKET_H */
