@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $superduper: xmms-mad.c,v 1.10 2003/12/28 15:18:40 sam Exp $
+ * $Id: xmms-mad.c,v 1.12 2004/05/16 16:54:38 sam Exp $
  */
 #include "config.h"
 #include "xmms-mad.h"
@@ -53,7 +53,7 @@ xmmsmad_init ()
 {
   ConfigFile *cfg;
   xmmsmad_config.http_buffer_size = HTTP_BUFFER_SIZE,
-  xmmsmad_config.fast_play_time_calc = FALSE;
+  xmmsmad_config.fast_play_time_calc = TRUE;
   xmmsmad_config.use_xing = TRUE;
   cfg = xmms_cfg_open_default_file();
   if (cfg)
@@ -345,7 +345,7 @@ get_iplugin_info (void)
   mad_plugin.about         = xmmsmad_about;
   mad_plugin.init          = xmmsmad_init;
   mad_plugin.set_eq        = xmmsmad_set_eq;
-  mad_plugin.configure     = NULL; /*xmmsmad_configure;*/
+  mad_plugin.configure     = xmmsmad_configure;
   mad_plugin.is_our_file   = xmmsmad_is_our_file;
   mad_plugin.play_file     = xmmsmad_play_file;
   mad_plugin.stop          = xmmsmad_stop;
